==> xlr-server-sql-25.3.0-512.1109-sources.jar: com/xebialabs/xlrelease/repository/sql/persistence/data/TaskRow.scala <==
package com.xebialabs.xlrelease.repository.sql.persistence.data

import com.xebialabs.deployit.plugin.api.reflect.Type
import com.xebialabs.xlrelease.domain.status.TaskStatus
import com.xebialabs.xlrelease.repository.query.TaskBasicData

import java.util.Date

case class TaskRow(
                    ciUid: Long,
                    releaseUid: Long,
                    taskId: String,
                    taskType: String,
                    title: String,
                    status: String,
                    statusLine: String,
                    owner: String,
                    team: String,
                    startDate: Date,
                    endDate: Date,
                    isAutomated: Boolean,
                    locked: Boolean,
                    plannedDuration: Int
                  )

object TaskRow {

  implicit class TaskDataOps(val data: TaskRow) {
    def asTaskData(taskId: String): TaskBasicData = {
      TaskBasicData(
        ciUid = data.ciUid,
        releaseUid = data.releaseUid,
        taskId = taskId, // to use provided full task ID instead of queried folder-less ID
        taskType = Type.valueOf(data.taskType),
        title = data.title,
        status = TaskStatus.valueOf(data.status.toUpperCase),
        statusLine = data.statusLine,
        owner = data.owner,
        team = data.team,
        startDate = data.startDate,
        endDate = data.endDate,
        isAutomated = data.isAutomated,
        locked = data.locked,
      )
    }
  }

}

==> xlr-server-sql-25.3.0-513.1502-sources.jar: com/xebialabs/xlrelease/repository/sql/persistence/data/TaskRow.scala <==
package com.xebialabs.xlrelease.repository.sql.persistence.data

import com.xebialabs.deployit.plugin.api.reflect.Type
import com.xebialabs.xlrelease.domain.id.CiUid
import com.xebialabs.xlrelease.domain.status.TaskStatus
import com.xebialabs.xlrelease.repository.query.TaskBasicData

import java.util.Date

case class TaskRow(
                    ciUid: CiUid,
                    releaseUid: CiUid,
                    taskId: String,
                    taskType: String,
                    title: String,
                    status: String,
                    statusLine: String,
                    owner: String,
                    team: String,
                    startDate: Date,
                    endDate: Date,
                    isAutomated: Boolean,
                    locked: Boolean,
                    plannedDuration: Int
                  )

object TaskRow {

  implicit class TaskDataOps(val data: TaskRow) {
    def asTaskData(taskId: String): TaskBasicData = {
      TaskBasicData(
        ciUid = data.ciUid,
        releaseUid = data.releaseUid,
        taskId = taskId, // to use provided full task ID instead of queried folder-less ID
        taskType = Type.valueOf(data.taskType),
        title = data.title,
        status = TaskStatus.valueOf(data.status.toUpperCase),
        statusLine = data.statusLine,
        owner = data.owner,
        team = data.team,
        startDate = data.startDate,
        endDate = data.endDate,
        isAutomated = data.isAutomated,
        locked = data.locked,
      )
    }
  }

}
